@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import AsyncIterable, Union, Final, \
+from typing import AsyncIterable, Union, \
   TYPE_CHECKING, Optional, cast, Tuple
 from inspect import iscoroutinefunction
 from pathlib import Path
@@ -7,6 +7,8 @@ import io
 
 from aiofile import AIOFile, LineReader
 
+from .types import Final
+
 if TYPE_CHECKING:  # keep mypy quiet
   from .path import AsyncPath
 
