@@ -1,8 +1,7 @@
 from __future__ import annotations
 from pathlib import PosixPath, WindowsPath, _NormalAccessor, \
   Path, PurePath, _ignore_error
-from typing import Optional, List, Union, AsyncIterable, \
-  Literal, Final
+from typing import Optional, List, Union, AsyncIterable
 from os import stat_result
 from stat import S_ISDIR, S_ISLNK, S_ISREG, S_ISSOCK, S_ISBLK, \
   S_ISCHR, S_ISFIFO
@@ -18,6 +17,7 @@ from .flavours import _async_windows_flavour, _async_posix_flavour
 from .wrap import coro_as_method_coro, func_as_method_coro, to_thread
 from .handle import IterableAIOFile, read_full_file
 from .scandir import EntryWrapper, scandir_async
+from .types import Final, Literal, FileMode
 
 
 DEFAULT_ENCODING: Final[str] = 'utf-8'
@@ -25,13 +25,6 @@ ON_ERRORS: Final[str] = 'ignore'
 NEWLINE: Final[str] = '\n'
 
 
-TextMode = \
-  Literal['r', 'w', 'a', 'x', 'r+', 'w+', 'a+', 'x+']
-BinaryMode = \
-  Literal['rb', 'wb', 'ab', 'xb', 'r+b', 'w+b', 'a+b', 'x+b']
-FileMode = Union[TextMode, BinaryMode]
-
-
 getcwd = func_as_corofunc(os.getcwd)
 close = func_as_corofunc(os.close)
 
@@ -386,7 +379,7 @@ class AsyncPath(Path, AsyncPurePath):
     return cls(cwd)
 
   @classmethod
-  async def home(cls) -> AsyncPath:
+  async def home(cls: type) -> AsyncPath:
     """Return a new path pointing to the user's home directory (as
     returned by os.path.expanduser('~')).
     """
@@ -411,7 +404,7 @@ class AsyncPath(Path, AsyncPurePath):
         other_st = await to_thread(other_path.stat)
 
       except AttributeError:
-        other_st = await to_thread(self._accessor.stat, other_path)
+        other_st = await to_thread(other_path._accessor.stat, other_path)
 
     return os.path.samestat(
       await self.stat(),
@@ -463,7 +456,7 @@ class AsyncPath(Path, AsyncPurePath):
     async for p in selector.select_from(self):
       yield p
 
-  async def absolute(self):
+  async def absolute(self) -> AsyncPath:
     """Return an absolute version of this path.  This function works
     even if the path doesn't point to anything.
     No normalization is done, i.e. all '.' and '..' will be kept along.
