@@ -10,11 +10,19 @@ try:
 except ImportError:
   from asyncio import get_running_loop
 
-  async def to_thread(func: Callable, /, *args, **kwargs) -> Any:
-    loop = get_running_loop()
-    ctx = contextvars.copy_context()
-    func_call = partial(ctx.run, func, *args, **kwargs)
-    return await loop.run_in_executor(None, func_call)
+  try:
+    async def to_thread(func: Callable, /, *args, **kwargs) -> Any:
+      loop = get_running_loop()
+      ctx = contextvars.copy_context()
+      func_call = partial(ctx.run, func, *args, **kwargs)
+      return await loop.run_in_executor(None, func_call)
+
+  except SyntaxError:
+    async def to_thread(func: Callable, *args, **kwargs) -> Any:
+      loop = get_running_loop()
+      ctx = contextvars.copy_context()
+      func_call = partial(ctx.run, func, *args, **kwargs)
+      return await loop.run_in_executor(None, func_call)
 
 
 CoroutineResult = Awaitable[Any]
